# eric7.Network.IRC.IrcIdentitiesEditDialog

Module implementing the identities management dialog.

### Global Attributes

None

### Classes

IrcIdentitiesEditDialog | Class implementing the identities management dialog.

### Functions

None

## IrcIdentitiesEditDialog

Class implementing the identities management dialog.

### Derived from

QDialog, Ui_IrcIdentitiesEditDialog

### Class Attributes

None

### Class Methods

None

### Methods

IrcIdentitiesEditDialog | Constructor
__checkCurrentIdentity | Private method to check the data for the current identity.
__refreshCurrentIdentity | Private method to read back the data for the current identity.
__updateIdentitiesButtons | Private slot to update the status of the identity related buttons.
__updateNicknameButtons | Private slot to update the nick name buttons except the up and down buttons.
__updateNicknameUpDownButtons | Private method to set the enabled state of the nick name up and down buttons.
accept | Public slot handling the acceptance of the dialog.
eventFilter | Public method to handle events for other objects.
on_addButton_clicked | Private slot to add a new idntity.
on_copyButton_clicked | Private slot to copy the selected identity.
on_deleteButton_clicked | Private slot to rename the selected identity.
on_identitiesCombo_currentIndexChanged | Private slot to handle the selection of an identity.
on_nicknameAddButton_clicked | Private slot to add a new nickname.
on_nicknameDeleteButton_clicked | Private slot to delete a nick name.
on_nicknameDownButton_clicked | Private slot to move the selected entry down one row.
on_nicknameEdit_textEdited | Private slot handling a change of the nick name.
on_nicknameUpButton_clicked | Private slot to move the selected entry up one row.
on_nicknamesList_itemSelectionChanged | Private slot handling the selection of a nick name.
on_renameButton_clicked | Private slot to rename the selected identity.
on_showPasswordButton_clicked | Private slot to show or hide the password.

### Static Methods

None

#### IrcIdentitiesEditDialog (Constructor)

IrcIdentitiesEditDialog(manager, identityName, parent=None)

Constructor

manager
  reference to the IRC network manager object (IrcNetworkManager)
identityName
  name of the identity to be selected (string)
parent
  reference to the parent widget (QWidget)

#### IrcIdentitiesEditDialog.__checkCurrentIdentity

__checkCurrentIdentity()

Private method to check the data for the current identity.

Return:
  flag indicating a successful check (boolean)

#### IrcIdentitiesEditDialog.__refreshCurrentIdentity

__refreshCurrentIdentity()

Private method to read back the data for the current identity.

#### IrcIdentitiesEditDialog.__updateIdentitiesButtons

__updateIdentitiesButtons()

Private slot to update the status of the identity related buttons.

#### IrcIdentitiesEditDialog.__updateNicknameButtons

__updateNicknameButtons()

Private slot to update the nick name buttons except the up and down buttons.

#### IrcIdentitiesEditDialog.__updateNicknameUpDownButtons

__updateNicknameUpDownButtons()

Private method to set the enabled state of the nick name up and down buttons.

#### IrcIdentitiesEditDialog.accept

accept()

Public slot handling the acceptance of the dialog.

#### IrcIdentitiesEditDialog.eventFilter

eventFilter(obj, evt)

Public method to handle events for other objects.

obj
  reference to the object (QObject)
evt
  reference to the event (QEvent)

Return:
  flag indicating that the event should be filtered out (boolean)

#### IrcIdentitiesEditDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to add a new idntity.

#### IrcIdentitiesEditDialog.on_copyButton_clicked

on_copyButton_clicked()

Private slot to copy the selected identity.

#### IrcIdentitiesEditDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot to rename the selected identity.

#### IrcIdentitiesEditDialog.on_identitiesCombo_currentIndexChanged

on_identitiesCombo_currentIndexChanged(index)

Private slot to handle the selection of an identity.

index (int)
  index of the selected entry

#### IrcIdentitiesEditDialog.on_nicknameAddButton_clicked

on_nicknameAddButton_clicked()

Private slot to add a new nickname.

#### IrcIdentitiesEditDialog.on_nicknameDeleteButton_clicked

on_nicknameDeleteButton_clicked()

Private slot to delete a nick name.

#### IrcIdentitiesEditDialog.on_nicknameDownButton_clicked

on_nicknameDownButton_clicked()

Private slot to move the selected entry down one row.

#### IrcIdentitiesEditDialog.on_nicknameEdit_textEdited

on_nicknameEdit_textEdited(nick)

Private slot handling a change of the nick name.

nick
  new nick name (string)

#### IrcIdentitiesEditDialog.on_nicknameUpButton_clicked

on_nicknameUpButton_clicked()

Private slot to move the selected entry up one row.

#### IrcIdentitiesEditDialog.on_nicknamesList_itemSelectionChanged

on_nicknamesList_itemSelectionChanged()

Private slot handling the selection of a nick name.

#### IrcIdentitiesEditDialog.on_renameButton_clicked

on_renameButton_clicked()

Private slot to rename the selected identity.

#### IrcIdentitiesEditDialog.on_showPasswordButton_clicked

on_showPasswordButton_clicked(checked)

Private slot to show or hide the password.

checked (bool)
  state of the button

Up